% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ivs.R
\name{ivs}
\alias{ivs}
\title{Conditional Distribution of optimal tuning paramter}
\usage{
ivs(X, y, wn, alpha = 0.1, method = c("normal", "asymptotic"),
  resample = FALSE, ...)
}
\arguments{
\item{X}{input matrix or design matrix}

\item{y}{response variable}

\item{wn}{weight function, default is \eqn{log(n) / n}, which correponds to
BIC criterion. For AIC, choose \eqn{2 / n}.}

\item{alpha}{value to specify confidence level.  it
corrsponds confidence interval \eqn{ (1 - alpha) * 100\% }}

\item{method}{used to estimate conditional distribution and confidence interval}

\item{resample}{whether a bootstrap sample is drawn to produce solution
path}

\item{...}{Other arguments that can be passed to \code{glmpath}}
}
\value{
\item{prob}{Estimated conditional probablity of tuning parameter being
selected as the optimal tuning paramter}
\item{CI}{Confidence intervals for conditional probality based on normal
assumption}
\item{model}{a \code{glmpath} object, which is the same the fit
\code{glmpath(X, y, family = 'gaussian')}}
\item{alpha}{the specified alpha level}
\item{method}{the specified method}
\item{wn}{the specified wn}
}
\description{
Estimate conditional distribution of optimal
tuning paramter based on either asymptotic distribution or normal assumption
}
\examples{
set.seed(0622)
X <- matrix(rnorm(50*10), 50, 10)
y <- X[,1:3] \%*\% c(1, 0.5, 1) + rnorm(50)
ivs_model = ivs(X,y, method = "norm")
summary(ivs_model)
plot(ivs_model)

# If a single model is favored by conditional probality,
# Using resampling to check solution path's unceintanty
ivs_model = ivs(X,y, method = "norm", resample = TRUE)
summary(ivs_model)
plot(ivs_model, label = TRUE)
}
